# pgtg_widgets
it will help you quickly and easily create a user interface for your PyGame application

try to start example_demonstration.py as main

> available widgets:

advice: sx/sy should be in range [1.8; 3] - these are the most elegant proportions

sc - should be pygame surface
    
x, y - coordinates on surface as in pygame (only int)
   
sx, sy - sizes of element as in pygame (only int)

grad - the degree of opacity of the element

border - border width in px (only int)

> Switch

col_bor, col_off, col_on - rgb colors of border, right half and left half

state - state of switch (bool)

time_tick - delay between ticks

> Button

color - color of button

text, font, text_color - button text settings

> ProgressBar

col_bor, col_off, col_on - rgb colors of border, right half and left half
